@@ -10,10 +10,10 @@ import gc
 import justpy as jp
 import os
 import sys
-import pandas as pd
 import psutil
 import socket
 import traceback
+import itertools
 from jpcore.demostarter import Demostarter
 from jpcore.tutorial import TutorialManager,Example
 from jpcore.demoapp import JustpyDemoApp
@@ -237,6 +237,9 @@ class DemoBrowser(BaseWebPage):
         jp.app.add_jproute("/demo/{demo_name}",self.show_demo)
         self.mounted={}
         self.page_load_count=0
+        self.endMount = 10
+        self.startMount = 0
+
         
     def optionalDebug(self,args):   
         '''
@@ -293,7 +296,7 @@ class DemoBrowser(BaseWebPage):
                     await self.add_demo(demo,i+1)
                 pass
             else:
-                for i,demo in enumerate(self.mounted):
+                for i,demo in enumerate(self.mounted.values()):
                     await self.add_demo_tolist(demo)
                     
             self.page_load_count+=1
@@ -319,6 +322,9 @@ class DemoBrowser(BaseWebPage):
             demo(JustpyDemoApp): the demo app to add
             video_size(int): the size of the video (default: 512)
         """
+        if isinstance(demo, str):
+            print(f"{demo} is a string not a JustpyDemoApp")
+            return
         video_link=demo.video_link(video_size=video_size)
         list_item_html = f"""<q-item clickable v-ripple>
                             <q-item-section avatar>{demo.example_source.img_link}</q-item-section>
@@ -337,6 +343,7 @@ class DemoBrowser(BaseWebPage):
         list_item.name = demo.name
         list_item.video_url = demo.video_url
         self.video_list.add_component(list_item,0)
+        
         def delete_list_item(btn, _msg):
             """
             delete a list item
@@ -359,20 +366,14 @@ class DemoBrowser(BaseWebPage):
     </q-drawer>"""
         self.setup(extra_html)
         try:
+
             self.video_list=self.bp.name_dict["thumbnail_list"]
             self.mount_all_btn=QBtn(label="Mount all",a=self.toolbar,classes="q-mr-sm",click=self.on_mount_all_btn_click)
-            
+            self.slider = jp.QRange(a=self.toolbar, classes='m-8 p-2', style='width: 600px', input=self.change_range, label=True,
+                                     label_always=True,value=[1, 10], min=1, max=len(self.demo_starter.demos), snap=True, markers=True)
+            self.mount_range_btn = QBtn(label=f'Mount range', a=self.toolbar, classes="q-mr-sm",click=self.on_mount_range_btn_click)
             self.video_size=512
             icon_size=32
-            lod=self.demo_starter.as_list_of_dicts()
-            for record in lod:
-                index=record["#"]
-                demo=self.demo_starter.demos[index-1]
-                example=self.tutorial_manager.examples_by_name.get(demo.name,None)
-                if example is not None:
-                    demo.example_source=example.example_source
-                    record["→"]=example.example_source.img_link
-            df=pd.DataFrame(lod)
             style='height: 90vh; width: 99%; margin: 0.25rem; padding: 0.25rem;'
             grid_options = """{
               'rowHeight': %s,
@@ -384,14 +385,41 @@ class DemoBrowser(BaseWebPage):
                 headerClass: 'font-bold'
             }
         }""" % icon_size
-            self.ag_grid=df.jp.ag_grid(a=self.main_page,style=style,options=grid_options )
-            self.ag_grid.html_columns = [1,2,3,4,5]
-            self.ag_grid.on('rowSelected', self.row_selected)
-            self.ag_grid.options.columnDefs[0].checkboxSelection = True
+            self.ag_grid=jp.AgGrid(a=self.main_page,style=style,options=grid_options )
+            self.reload_grid()
         except Exception as ex:
             self.handleException(ex)
         return self.wp
     
+    def get_lod(self):
+        self.lod=self.demo_starter.as_list_of_dicts()
+        for record in self.lod:
+            index=record["#"]
+            demo=self.demo_starter.demos[index-1]
+            example=self.tutorial_manager.examples_by_name.get(demo.name,None)
+            if example is not None:
+                demo.example_source=example.example_source
+                record["→"]=example.example_source.img_link
+
+    def reload_grid(self):
+        self.get_lod()
+        self.columnDefs= []
+        if len(self.lod)>0:
+            first=self.lod[0]
+            for key in first.keys():
+                self.columnDefs.append({
+                    'headerName': key, 
+                    'field': key}
+                )
+        #self.columnDefs= [
+        #        {'headerName': 'Name', 'field': 'name'},
+        #        {'headerName': 'Age', 'field': 'age'},
+        #]
+        self.columnDefs[0]["checkboxSelection"] = True
+        self.ag_grid.load_lod(lod=self.lod, columnDefs=self.columnDefs)
+        self.ag_grid.html_columns = [1,2,3,4,5]
+        self.ag_grid.on('rowSelected', self.row_selected)
+  
     async def row_selected(self,msg):
         """
         a grid row has been selected
@@ -402,6 +430,7 @@ class DemoBrowser(BaseWebPage):
                 index = row_data["#"]
                 demo=self.demo_starter.demos[index-1]
                 await self.add_demo(demo,index)
+                self.reload_grid()
             except Exception as ex:
                 self.handleException(ex)
         
@@ -431,8 +460,28 @@ class DemoBrowser(BaseWebPage):
         print(f"mount all has been clicked ... trying to mount {total} demos ")
         for i,demo in enumerate(self.demo_starter.demos):
             self.mount(demo,i+1)
+
         await self.wp.update()
-            
+
+    async def on_mount_range_btn_click(self,_msg):
+        """
+        mount all button has been clicked
+        """
+        #total=len(self.demo_starter.demos)
+
+        print(f"mount range has been clicked ... trying to mount {self.endMount-self.startMount +1}  demos between {self.startMount} and {self.endMount}")
+        for i,demo in enumerate(self.demo_starter.demos[self.startMount-1 : self.endMount-1], self.startMount):
+            self.mount(demo, i)
+        self.reload_grid()
+        await self.wp.update()
+
+    def change_range(self, _msg):
+        self.endMount = max(_msg.value.values())
+        self.startMount = min(_msg.value.values())
+        print(f'{self.startMount} - {self.endMount}')
+
+
+
     def show_demo(self,request):
         """
         show a demo by name
