@@ -6,7 +6,6 @@ Created on 2022-09-02
 import asyncio
 import fnmatch
 import inspect
-import importlib
 import json
 import logging
 import os
@@ -22,7 +21,7 @@ from sys import platform
 from multiprocessing import Process
 from threading import Thread
 from starlette.applications import Starlette
-from starlette.routing import Route,request_response
+from starlette.routing import Route
 from starlette.endpoints import HTTPEndpoint
 from starlette.responses import HTMLResponse, JSONResponse,PlainTextResponse, Response
 from starlette.templating import Jinja2Templates
@@ -33,6 +32,7 @@ from jpcore.justpy_config import DECKGL, FAVICON, HIGHCHARTS,HTML_404_PAGE,KATEX
 from jpcore.justpy_config import NO_INTERNET, PLOTLY, SECRET_KEY, SESSION_COOKIE_NAME, SESSIONS
 from jpcore.justpy_config import STATIC_DIRECTORY,STATIC_NAME
 from jpcore.justpy_config import QUASAR, QUASAR_VERSION,TAILWIND, VEGA
+from jpcore.justpy_config import FRONTEND_ENGINE_TYPE
 from jpcore.template import Context
 from jpcore.webpage import WebPage
 from itsdangerous import Signer
@@ -54,6 +54,13 @@ component_file_list = create_component_file_list()
 grand_parent = pathlib.Path(__file__).parent.parent.resolve()
 template_dir=f"{grand_parent}/justpy/templates"
 
+lib_dir = os.path.join(template_dir, "js", FRONTEND_ENGINE_TYPE)
+# remove .js extension
+FRONTEND_ENGINE_LIBS = [fn[:-3]
+                        for fn in os.listdir(lib_dir)
+                        if fnmatch.fnmatch(fn, "*.js")
+                        ]
+
 TEMPLATES_DIRECTORY = config(
     "TEMPLATES_DIRECTORY", cast=str, default=template_dir
 )
@@ -360,6 +367,8 @@ class JustpyApp(Starlette):
             "options": template_options,
             "page_options": page_options,
             "html": load_page.html,
+            "frontend_engine_type": FRONTEND_ENGINE_TYPE,
+            "frontend_engine_libs": FRONTEND_ENGINE_LIBS
         }
         # wrap the context in a context object to make it available
         context_obj = Context(context)
@@ -599,80 +608,4 @@ class JustpyServer:
 
         """
         url = f"http://{self.host}:{self.port}{path}"
-        return url
-
-class JustpyDemoApp:
-    """
-    a justpy application
-    """
-
-    def __init__(self,examples_dir:str,pymodule_file:str, wpfunc: typing.Callable = None, debug:bool=False,**kwargs):
-        """
-        Args:
-            examples_dir(str): the root directory for the examples
-            pymodule_file(str): the python module path where the app resides
-            wpfunc(Callable): the webpage function to call
-            debug(bool): if True switch on debug mode
-            **kwargs: further keyword arguments to pass to the webpage function
-        """
-        self.examples_dir=examples_dir
-        self.pymodule_file = pymodule_file
-        with open(self.pymodule_file, "r") as sourcefile:
-            self.source = sourcefile.read()
-            self.check_demo()
-        source_file=pymodule_file
-        self.source_file=source_file.replace(self.examples_dir+"/","")
-        self.source_link=f"""<a href="https://github.com/justpy-org/justpy/blob/master/examples/{self.source_file}">{self.source_file}</a>"""
-        self.video_url=None
-        self.try_it_url=None
-        self.name=os.path.basename(self.source_file).replace(".py","")
-        self.wpfunc = wpfunc
-        self.debug=debug
-        self.status=""
-        self.kwargs = kwargs
-
-    def check_demo(self):
-        """
-        Check whether this is a demo
-        """
-        self.is_demo = False
-        if "Demo(" or "Demo (" in self.source:
-            func_match = re.search(
-                """Demo[ ]?[(]["'](.*)["'],\s*(.*?)(,.*)*[)]""", self.source
-            )
-            if func_match:
-                self.description = func_match.group(1)
-                self.wpfunc_name = func_match.group(2)
-                # jenkins could have /var/lib/jenkins/jobs/justpy/workspace/examples/charts_tutorial/pandas/women_majors2.py is not a demo
-                module_match = re.search(
-                    "justpy/(workspace/)?(examples/.*)[.]py", self.pymodule_file
-                )
-                if module_match:
-                    self.pymodule = module_match.group(2)
-                    self.pymodule = self.pymodule.replace("/", ".")
-                    self.is_demo = not "lambda" in self.wpfunc_name
-                return
-
-    def mount(self, app:JustpyApp):
-        """
-        mount me on the given app
-
-        Args:
-            app(JustpyApp): the app to mount me on
-        """
-        demo_module = importlib.import_module(self.pymodule)
-        self.wpfunc = getattr(demo_module, self.wpfunc_name)
-        if self.wpfunc is None:
-            raise Exception(f"can't start {self.pymodule_file} -wpfunc/endoint is None")
-        # https://fastapi.tiangolo.com/advanced/sub-applications/
-        name=self.wpfunc.__name__
-        endpoint=app.response(self.wpfunc)
-        # https://github.com/encode/starlette/issues/734
-        mount_app=request_response(endpoint)
-        if self.debug:
-            print(f"mounting  {str(self)}")
-        app.mount(f"/{name}",mount_app,name)
-
-    def __str__(self):
-        text = f"{self.pymodule}:{self.wpfunc_name}:{self.description}"
-        return text
+        return url
\ No newline at end of file
