@@ -4,6 +4,10 @@ Created on 2022-09-08
 @author: wf
 '''
 import asyncio
+
+from selenium.webdriver.remote.webdriver import BaseWebDriver
+from selenium.webdriver.support.wait import WebDriverWait
+
 from tests.base_server_test import BaseAsynctest
 from tests.browser_test import SeleniumBrowsers
 from tests.basetest import Basetest
@@ -35,4 +39,14 @@ class BaseSeleniumTest(BaseAsynctest):
         await asyncio.sleep(self.server.sleep_time)
         Demo.testmode = True
         return browser
-        
\ No newline at end of file
+
+    def get_waiting_browser(self, browser: BaseWebDriver, timeout: float = 5.0):
+        """
+        Return a waiting webdriver for the given driver/browser
+
+        Args:
+            browser: WebDriver
+            timeout: maximum time to wait
+        """
+        driver = WebDriverWait(browser, timeout)
+        return driver
