@@ -11,7 +11,6 @@ import time
 @jp.app.middleware("http")
 async def add_process_time_header(request: Request, call_next):
     start_time = time.time()
-    func=request.app.get_func_for_request(request)
     response = await call_next(request)
     process_time = time.time() - start_time
     response.headers["X-Process-Time"] = str(process_time)
@@ -31,7 +30,7 @@ class TestMiddleWare(BaseClienttest):
     
     def setUp(self, debug=False, profile=True):
         BaseClienttest.setUp(self, debug=debug, profile=profile)
-        self.app.prioritize_routes()
+        #self.app.prioritize_routes()
     
     def test_middleware(self):
         """
