@@ -52,7 +52,7 @@ class TestRouteAndUrlFor(BaseClienttest):
 
     def setUp(self, debug=False, profile=True):
         BaseClienttest.setUp(self, debug=debug, profile=profile)
-        self.app.prioritize_routes()
+        #self.app.prioritize_routes()
         
     def testStarletteRoutes(self):
         """
